#
# spec file for package newt (Version 0.52.10)
#
# Copyright (c) 2008 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           newt
Url:            https://fedorahosted.org/newt/
Summary:        Nifty Erik's Windowing Toolkit
Version:        0.52.10
Release:        4.1
%define         soname 0_52
License:        LGPL v2.1 or later
Group:          System/Libraries
Source:         %name-%version.tar.bz2
Source10:       %name-rpmlintrc
Requires:       libnewt%soname = %version
BuildRequires:  popt-devel python-devel slang-devel
%if 0%{?suse_version} < 1020
BuildRequires:  libpng-devel
%endif
# needed for tutorial.pdf
BuildRequires:  docbook-toys
%if 0%{?sles_version} == 9
BuildRequires:  jadetex
%endif
%{py_requires}
#
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Newt is a programming library for color text-mode, widget-based user
interfaces.  Newt can be used to add stacked windows, entry widgets,
checkboxes, radio buttons, labels, plain text fields, scrollbars, etc.,
to text mode user interfaces.

This package also contains a Dialog replacement called whiptail. Newt
is based on the slang library.



Authors:
--------
    Erik Troan <ewt@redhat.com>

%package -n libnewt0_52
License:        LGPL v2.1 or later
Summary:        Shared libraries for Nifty Erik's Windowing Toolkit
Group:          System/Libraries
#

%description -n libnewt0_52
This package contains the shared libraries needed by programs built
with newt.

Newt is a programming library for color text-mode widget-based user
interfaces.  Newt can be used to add stacked windows, entry widgets,
check boxes, radio buttons, labels, plain text fields, scrollbars,
etc., to text mode user interfaces.



Authors:
--------
    Erik Troan <ewt@redhat.com>

%package devel
License:        LGPL v2.1 or later
Summary:        Development files for the Newt windowing toolkit
Requires:       libnewt%soname = %{version}
Requires:       python-devel
Requires:       slang-devel
Requires:       popt-devel 
Recommends:     newt = %{version}
Group:          Development/Libraries/C and C++
#

%description devel
This package contains the header files and libraries necessary for
developing applications which use newt.

Newt is a development library for text mode user interfaces.

Install newt-devel if you want to develop applications which depend on
newt.



Authors:
--------
    Erik Troan <ewt@redhat.com>

%package doc
License:        LGPL v2.1 or later
Summary:        Tutorial for Nifty Erik's Windowing Toolkit
Group:          Documentation/Howto
#

%description doc
This package contains a tutorial about the Newt windowing toolkit.

Newt is a programming library for color text-mode, widget-based user
interfaces.  Newt can be used to add stacked windows, entry widgets,
check boxes, radio buttons, labels, plain text fields, scrollbars,
etc., to text mode user interfaces. Newt is based on the slang library.



Authors:
--------
    Erik Troan <ewt@redhat.com>

%package static
License:        LGPL v2.1 or later
Summary:        Static libraries of Nifty Erik's Windowing Toolkit
Requires:       newt-devel = %{version}
Group:          Development/Libraries/C and C++
#

%description static
This package contains the static libraries needed to compile programs
based on newt which don't need the shared libraries. Install it if you
need to link statically with libnewt.

Newt is a programming library for color text-mode widget-based user
interfaces.  Newt can be used to add stacked windows, entry widgets,
check boxes, radio buttons, labels, plain text fields, scrollbars,
etc., to text mode user interfaces.



Authors:
--------
    Erik Troan <ewt@redhat.com>

%package -n python-newt
License:        GPL v2 only; GPL v2 or later; LGPL v2.1 or later
Summary:        Python bindings for newt
Group:          System/Libraries
Requires:       newt = %{version}
Provides:       newt-python = %{version}
Obsoletes:      newt-python < 0.52.10
#

%description -n python-newt
The newt-python package contains the Python bindings for the newt
library providing a python API for creating text mode interfaces.



Authors:
--------
    Erik Troan <ewt@redhat.com>

%prep
%setup -q

%build
# gpm support seems to smash the stack
# --with-gpm-support
%configure --without-tcl
## make depend
make %{?jobs:-j%jobs} all

%install
make PYTHONVERS="python%{py_ver}" instroot="%buildroot" install install-sh
# currently we don't support these languages
# FIXME: add to filesystem
for lang in bal sr@latin wo; do
  rm -rf %buildroot%_datadir/locale/$lang
done
#
# prepare defaultdocdir with examples and scripts
#
install -d -m 755 %buildroot/%_defaultdocdir/%name/examples
# install COPYING file
install -m 644 COPYING %buildroot/%_defaultdocdir/%name/
# install example scripts
install -m 755 peanuts.py %buildroot/%_defaultdocdir/%name/examples/
install -m 755 popcorn.py %buildroot/%_defaultdocdir/%name/examples/
#
# create tutorial.pdf documentation
#
install -m 644 tutorial.sgml %buildroot/%_defaultdocdir/%name/
pushd %buildroot/%_defaultdocdir/%name/ 1>/dev/null
db2pdf tutorial.sgml
rm tutorial.{aux,log,out} CATALOG.* *.dsl
popd 1>/dev/null
%find_lang %{name}

%clean
rm -rf %buildroot

%post -n libnewt%soname -p /sbin/ldconfig

%postun -n libnewt%soname -p /sbin/ldconfig

%files -f %{name}.lang
%defattr (-,root,root)
%dir %_defaultdocdir/%name
%doc %_defaultdocdir/%name/COPYING
%{_bindir}/whiptail
%{_mandir}/man1/whiptail.1*

%files -n libnewt0_52
%defattr (-,root,root)
%{_libdir}/libnewt.so.*

%files devel
%defattr (-,root,root)
%{_includedir}/newt.h
%{_libdir}/libnewt.so

%files doc
%defattr (-,root,root)
%doc %_defaultdocdir/%name/tutorial.*

%files static
%defattr (-,root,root)
%{_libdir}/libnewt.a

%files -n python-newt
%defattr(-,root,root)
%dir %_defaultdocdir/%name/examples
%doc %_defaultdocdir/%name/examples/*.py 
%{py_sitedir}/*

%changelog
* Mon Sep  1 2008 lrupp@suse.de
- update to 0.52.10:
  + added support for help
  + added cusor on/off stuff
- rename newt-python to python-newt to follow the naming policy
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Mon Apr  7 2008 lrupp@suse.de
- update to 0.52.9:
  + handle component destruction (patch by Richard W.M. Jones)
  + fix newtWinEntry definition
  + don't use uninitialized values in newtWinMenu
  + remove workarounds for old bug in SLsmg_write_nstring
  + improve SIGWINCH handling in form
  + don't abort from whiptail gauge on SIGWINCH
  + redisplay also last line
  + update Polish translation
  + enable slang utf8 mode (rh#425992)
  + support --disable-nls option (patch by Natanael Copa)
  + redraw screen when using entry in euc encodings
- removed upstreamed patches
- devel package should require poptd-, python- and slang-devel and
  recommend the main package (not really needed)
- updated rpmlintrc
* Mon Dec 17 2007 lrupp@suse.de
- split libnewt0_52 to follow the shared library packaging policy
- build on older distributions
- build parallel
* Thu Oct 11 2007 lrupp@suse.de
- split python module to -python subpackage
- add back support for list of Entries in EntryWindow prompts in
  snack (RH#248878) (newt-0.52.7-snack.patch)
- fix segfault in whiptail when no entry is selected in radiolist
  (newt-0.52.7-whiptail.patch)
- fix handling of UTF-8 characters (#289291)
  (newt-0.52.7-utf8.patch)
* Tue Sep 11 2007 cthiel@suse.de
- removed bogus Provides: snack (to avoid name clash with package snack)
* Tue Jun 26 2007 lrupp@suse.de
- update to 0.52.7:
  + add support to snack for multiple selection and border in listbox
    and cursorAtEnd in entry (patch by Shawn Starr)
  + fix scrollbar positioning in listbox
  + cope with backward system time jumps (RH#240691)
  + free helplines and windows in newtFinished, check for overflow (RH#239992)
- remove included patches
- created doc package for tutorial (N#287087)
* Wed Jun 13 2007 lrupp@suse.de
- included patches from Miroslav Lichvar:
  + fix cursor positioning when setting entry or checkbox flags
    (newt-0.52.6-cursor.patch)
  + fix counting of items in checkboxtree
    (newt-0.52.6-countitems.patch)
  + fix some memory leaks
    (newt-0.52.6-memleaks.patch)
  + fix entry scrolling (RH#234829) and
  + fix multibyte character handling in entry
    (newt-0.52.6-entry.patch)
- disable gpm-support - seems to smash the stack
- remove libbz2-1 from buildreq
- re-arange buildrequires
* Tue Jun  5 2007 ro@suse.de
- buildreq: libbz2 -> libbz2-1
* Sun Apr  1 2007 lrupp@suse.de
- added distribution specfic parts for build service
- added libbz2 to BuildRequires for suse_version > 1020
* Wed Mar  7 2007 lrupp@suse.de
- update to 0.52.6:
  + add newtSetColor() to allow changing individual colors
  + add newtPopWindowNoRefresh() (patch by Forest Bond)
- branched newt-static package containing static library
* Wed Feb 14 2007 lrupp@suse.de
- update to 0.52.5
  + provide option to change text of buttons (rh#126768)
  + don't add escape key to hot keys by default (rh#216157)
  + fix cursor position in checkboxtree, radio button and checkbox
  + don't force monochrome terminals to output colors
  + highlight active compact button on monochrome terminals
  + update translations from debian
- removed unnecessary ldconfig call in devel package
- removed obsolete newt-0.52.4-if1close.patch
* Thu Dec 21 2006 lrupp@suse.de
- new upstream version 0.52.4: patches included upstream
  + fix entry corruption when reading multibyte characters
    and double width character handling
  + avoid overflow/crash in scale
- makefile, configure and spec cleanup
- package whiptail.1 and locale files
* Fri Sep 22 2006 lrupp@suse.de
- fix build with python 2.5 (thanks to aj)
- useful fixes from RH bugzilla included:
  * #137957 : fix screen corruption
  * #81352  : fix help dialog
  * #83203  : make textbox with scrollbar focusable
  * #86074  : turn off cursor when entry terminated form
  * #186053 : better handling of listbox and checkboxtree focus
  * #187545 : be more color friendly to 8-color terminals
  * #189981 : fix handling windows larger than screen size
  * fix checkboxtree positioning
  * unfocus when displaying help
  * fix double width character handling in checkboxtree and listbox
* Tue May  9 2006 lrupp@suse.de
- add "Provides: snack" to specfile
- do not build whiptcl to avoid dependency on tcl (RH #177346)
  (whiptcl is currently not used by anything)
- Apply patch by Bill Nottingham (thanks) to improve scrollbar appearance
  (RH #174771)
- Fix a crash in checkboxtree.c (RH #165347)
- draw correct dialog sizes on the screen (see RH #185950) - applying
  patch from Tomas Mraz (thanks)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 12 2005 lrupp@suse.de
- new version 0.52.2
- include whiptcl.so
* Thu Nov 10 2005 lrupp@suse.de
- only do gpmclose if gpmopen succeeed
  (see https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=118530)
- include example files (peanuts.py, popcorn.py) in devel package
- use "-fPIC -Wall -fno-strict-aliasing" in CFLAGS
* Mon Sep 26 2005 mls@suse.de
- make devel package require base package
* Mon Jul 25 2005 lrupp@suse.de 0.51.6
- use of %%run_ldconfig
* Fri Jun 17 2005 lrupp@suse.de 0.51.6
- use more macros: fix build on 64bit
* Fri Jun 17 2005 lrupp@suse.de 0.51.6
- use $RPM_OPT_FLAGS
- delete /usr/lib/phyton in build to avoid errors from abuild
  => we've a symlink to /usr/lib/python2.4
* Thu Jun 16 2005 ro@suse.de
- fix files pagaged twice (real path and over symlink)
* Tue Feb 15 2005 ro@suse.de
- added python deps
* Mon Jan 24 2005 ro@suse.de
- fix lib64 build
* Tue Nov 30 2004 cwh@suse.de
- updated to 0.51.6
* Wed Jun  2 2004 ro@suse.de
- get rid of some compiler warnings
* Thu Feb 26 2004 hmacht@suse.de
- building as non-root
* Tue Feb 24 2004 cwh@suse.de
- added soname link to package
* Mon Sep 15 2003 cwh@suse.de
- removed wrong "Provides: snack" from spec-file
* Wed Aug 20 2003 ro@suse.de
- expand filelist
- fix lib64 issues
* Wed Aug 20 2003 cwh@suse.de
- fixed to compile with tcl8.4
* Tue Jan 16 2001 schwab@suse.de
- Fix missing -fPIC in Makefile.
- Fix use of varargs.
* Wed Nov 29 2000 ro@suse.de
- changed neededforbuild <tcld> to <tcl-devel>
* Wed Nov 29 2000 smid@suse.cz
- subpackage renamed: newtd => newt-devel
* Fri Nov 24 2000 ro@suse.de
- fixes for 2.0-python
* Sun Oct 29 2000 kukuk@suse.de
- Add python-devel to need for build
* Mon May 22 2000 smid@suse.cz
- fixed to compile with tcl8.3
* Wed May 10 2000 nadvornik@suse.cz
- update to 0.50.8
- added BuildRoot
* Mon Jan 17 2000 nashif@suse.de
- Initial Release ( Version 0.50)
